@@ -1,7 +1,7 @@
 package App::CalendarDatesUtils;
 
-our $DATE = '2019-02-14'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2019-05-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -28,6 +28,13 @@ $SPEC{list_calendar_dates} = {
     summary => 'List dates from one or more Calendar::Dates::* modules',
     args => {
         year => {
+            summary => 'Specify year of dates to list',
+            description => <<'_',
+
+The default is to list dates in the current year. You can specify all_years
+instead to list dates from all available years.
+
+_
             schema => 'int*',
             pos => 0,
         },
@@ -39,17 +46,21 @@ $SPEC{list_calendar_dates} = {
             schema => ['int*', in=>[1, 31]],
             pos => 2,
         },
+        all_years => {
+            summary => 'List dates from all available years '.
+                'instead of a single year',
+            schema => 'true*',
+        },
         modules => {
             'x.name.is_plural' => 1,
             'x.name.singular' => 'modules',
             schema => ['array*', of=>'perl::modname*'],
             cmdline_aliases => {m=>{}},
-            'x.completion' => [perl_modname => {ns_prefix=>'Calendar::Dates'}],
+            'x.element_completion' => [perl_modname => {ns_prefix=>'Calendar::Dates::'}],
         },
-        all => {
+        all_modules => {
             summary => 'Use all installed Calendar::Dates::* modules',
             schema => 'true*',
-            cmdline_aliases => {a=>{}},
         },
         detail => {
             schema => 'bool*',
@@ -57,7 +68,12 @@ $SPEC{list_calendar_dates} = {
         },
     },
     args_rels => {
-        req_one => ['modules', 'all'],
+        'req_one&' => [
+            ['modules', 'all_modules'],
+        ],
+        'choose_one&' => [
+            ['year', 'all_years'],
+        ],
     },
 };
 sub list_calendar_dates {
@@ -68,7 +84,7 @@ sub list_calendar_dates {
     my $day  = $args{day};
 
     my $modules;
-    if ($args{all}) {
+    if ($args{all_modules}) {
         $modules = list_calendar_dates_modules()->[2];
     } else {
         $modules = $args{modules};
@@ -80,14 +96,22 @@ sub list_calendar_dates {
         (my $mod_pm = "$mod.pm") =~ s!::!/!g;
         require $mod_pm;
 
-        my $res;
-        eval { $res = $mod->get_entries($year, $mon, $day) };
-        if ($@) {
-            warn "Can't get entries from $mod: $@, skipped";
-            next;
+        my $years;
+        if ($args{all_years}) {
+            $years = [ $mod->get_min_year .. $mod->get_max_year ];
+        } else {
+            $years = [ $year ];
         }
 
-        push @rows, @$res;
+        for my $y (@$years) {
+            my $res;
+            eval { $res = $mod->get_entries($y, $mon, $day) };
+            if ($@) {
+                warn "Can't get entries from $mod (year=$y): $@, skipped";
+                next;
+            }
+            push @rows, @$res;
+        }
     }
 
     unless ($args{detail}) {
@@ -112,7 +136,7 @@ App::CalendarDatesUtils - Utilities related to Calendar::Dates
 
 =head1 VERSION
 
-This document describes version 0.002 of App::CalendarDatesUtils (from Perl distribution App-CalendarDatesUtils), released on 2019-02-14.
+This document describes version 0.003 of App::CalendarDatesUtils (from Perl distribution App-CalendarDatesUtils), released on 2019-05-25.
 
 =head1 DESCRIPTION
 
@@ -143,10 +167,14 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<all> => I<true>
+=item * B<all_modules> => I<true>
 
 Use all installed Calendar::Dates::* modules.
 
+=item * B<all_years> => I<true>
+
+List dates from all available years instead of a single year.
+
 =item * B<day> => I<int>
 
 =item * B<detail> => I<bool>
@@ -157,6 +185,11 @@ Use all installed Calendar::Dates::* modules.
 
 =item * B<year> => I<int>
 
+Specify year of dates to list.
+
+The default is to list dates in the current year. You can specify all_years
+instead to list dates from all available years.
+
 =back
 
 Returns an enveloped result (an array).
